summaryrefslogtreecommitdiffstats
path: root/ktouch/src/ktouchstatus.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-11 04:44:41 +0000
commita374efce3a207b39514be3c52264091400ce297e (patch)
tree77bdf654b55826d4f59b53a5621310206bcaead1 /ktouch/src/ktouchstatus.h
parentf81a494f3957d5cf38c787973415597941934727 (diff)
downloadtdeedu-a374efce3a207b39514be3c52264091400ce297e.tar.gz
tdeedu-a374efce3a207b39514be3c52264091400ce297e.zip
TQt4 port kdeedu
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdeedu@1236073 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'ktouch/src/ktouchstatus.h')
-rw-r--r--ktouch/src/ktouchstatus.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/ktouch/src/ktouchstatus.h b/ktouch/src/ktouchstatus.h
index 72bb6acc..d44d91c4 100644
--- a/ktouch/src/ktouchstatus.h
+++ b/ktouch/src/ktouchstatus.h
@@ -22,20 +22,21 @@
/** This is the implementation of the status widget (at the top of the main view).
* It simply displays the status but does not have a functionality of its own.
* Everythings is calculated in the trainer (see KTouchTrainer)and then displayed
* using the updateStatus() member function.
* The "new characters" string is set using the member function setNewChars().
*/
-class KTouchStatus : public KTouchStatusLayout {
+class KTouchtqStatus : public KTouchStatusLayout {
Q_OBJECT
+ TQ_OBJECT
public:
/// Constructor
- KTouchStatus(TQWidget *parent);
+ KTouchtqStatus(TQWidget *tqparent);
/// Called when the preferences have changed in the configuration dialog.
void applyPreferences();
/// Sets the new characters text.
void setNewChars(const TQString& newChars);
/// Updates the level LCD and the correctness progress bar
- void updateStatus(unsigned int level, double correctness);
+ void updatetqStatus(unsigned int level, double correctness);
};
#endif // KTOUCHSTATUS_H
@@ -22,20 +22,21 @@
* It simply displays the status but does not have a functionality of its own.
* Everythings is calculated in the trainer (see KTouchTrainer)and then displayed
- * using the updateStatus() member function.
+ * using the updatetqStatus() member function.
* The "new characters" string is set using the member function setNewChars().
*/